Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(11)

Unified Diff: pkg/analysis_server/lib/plugin/navigation.dart

Issue 1303033010: Navigation extension point. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: tweaks Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/plugin/navigation.dart
diff --git a/pkg/analysis_server/lib/plugin/completion.dart b/pkg/analysis_server/lib/plugin/navigation.dart
similarity index 56%
copy from pkg/analysis_server/lib/plugin/completion.dart
copy to pkg/analysis_server/lib/plugin/navigation.dart
index 8fd6159b783a5672789c4521456e242423ad3556..23603f06f64e87eb893e38918fa0abc430d1f97d 100644
--- a/pkg/analysis_server/lib/plugin/completion.dart
+++ b/pkg/analysis_server/lib/plugin/navigation.dart
@@ -3,20 +3,20 @@
// BSD-style license that can be found in the LICENSE file.
/**
* Support for client code that extends the analysis server by adding new code
* completion contributors.
*/
-library analysis_server.plugin.completion;
+library analysis_server.plugin.navigation;
-import 'package:analysis_server/completion/completion_core.dart';
+import 'package:analysis_server/analysis/navigation/navigation_core.dart';
import 'package:analysis_server/src/plugin/server_plugin.dart';
import 'package:plugin/plugin.dart';
/**
* The identifier of the extension point that allows plugins to register code
* completion contributors. The object used as an extension must be a
* [CompletionContributor].
*/
-final String COMPLETION_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join(
+final String NAVIGATION_CONTRIBUTOR_EXTENSION_POINT_ID = Plugin.join(
ServerPlugin.UNIQUE_IDENTIFIER,
- ServerPlugin.COMPLETION_CONTRIBUTOR_EXTENSION_POINT);
+ ServerPlugin.NAVIGATION_CONTRIBUTOR_EXTENSION_POINT);
« no previous file with comments | « pkg/analysis_server/lib/analysis/navigation/navigation_core.dart ('k') | pkg/analysis_server/lib/src/analysis_server.dart » ('j') | no next file with comments »

Powered by Google App Engine
@@ -3,20 +3,20 @@
// BSD-style license that can be found in the LICENSE file.
/**
- * Support for client code that extends the analysis server by adding new code
- * completion contributors.
+ * Support for client code that extends the analysis server by adding new
+ * navigation contributors.
*/
@@ -3,20 +3,20 @@
import 'package:plugin/plugin.dart';
/**
- * The identifier of the extension point that allows plugins to register code
- * completion contributors. The object used as an extension must be a
- * [CompletionContributor].
+ * The identifier of the extension point that allows plugins to register
+ * navigation contributors. The object used as an extension must be
+ * a [NavigationContributor].
*/
This is Rietveld 408576698